@@ -313,6 +313,17 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.day_calib_signals_list = list(self.day_calib_signals_list )
         self.day_calib_signals_list.sort()
 
+        #self.selected_indice = None
+        self.selected_indice = 'slope_lsTrue13852729'
+
+        self.selected_counter = 0
+        sig_counter = 0
+        for meArg in self.day_calib_signals_list:
+            readable_label = signal_utility.get_readable_label(meArg)
+            if readable_label == 'slope_lsTrue13852729':
+                self.selected_counter = sig_counter
+            sig_counter = sig_counter + 1
+
         self.minute_signal_mapping={}
         minute_max_lookback_window = 0
         for me_signal in self.min_calib_signals_list:
